#!/bin/bash
#
# packager         : Fred. Galusik <fredg> (fredgk~AT~gmail.com)
#
# source location  : http://lame.sourceforge.net/download.php
#
# last revised     : 15/10/2006
#
# additional files : 
#

#
# what package is going to be built
#
# packageversion='1z32' means:
# 1  -> build 1,
# z  -> ZenWalk
# 32 -> ZenWalk version 3.2
#
softname='lame'
softversion='3.97'
packageversion='1z32'

#
# ZenWalk standard: CPU type and architecture
#
# arch='i486' -> the compiler uses only 80486 instructions
# cpu='i686'  -> the optimising is done for a PII and above CPU
#
arch='i486'
cpu='i686'

#
# the package 'destination'
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "heavy" computer: 6 build-jobs at once
#
# numjobs='-j6'
#
# "light" computer: 2 build-jobs at once
#
numjobs='-j2'

#
# parameters needed for the build process
#
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

#
# prepare the build result directory
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/src/$softname-$softversion

#
# put slack-desc in place. Either a supplied one, or some default
# text.
#
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: MPEG Audio Layer III (MP3) encoder
$softname:
$softname: LAME is considered the best MP3 encoder at mid-high bitrates
$softname: and at VBR.
$softname: 
$softname:
$softname:
$softname:
$softname: 
$softname:
$softname:
EOF

#
# extract the source code
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar zxvf $srcpkg
cd $src

#
# configure package for compilation
#

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --sysconfdir=/etc \
      --localstatedir=/var/lib \

#
# make package
#
    make $numjobs DESTDIR=$dest

#
# install package to the target directory
#
    make install DESTDIR=$dest
    
#
# add 'default' files
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      API COPYING INSTALL README ChangeLog README.WINGTK STYLEGUIDE TODO HACKING USAGE INSTALL INSTALL.configure LICENSE\
      $dest/usr/doc/$softname-$softversion

#
# move these doc files to the right place
#
mv $dest/usr/share/doc/lame/* $dest/usr/doc/$softname-$softversion
rm -rf $dest/usr/share

#
# Strip Executables
# (Comment out these lines if debugging info is needed)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compress Man Pages
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

#
# put the ZenWalk build in the right directory
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# set target permissions
#
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

#
# update the libs
#
cat << "EOF" > $dest/install/doinst.sh
/sbin/ldconfig
EOF

#
# real packaging work:
#
cd $dest
makepkg -l y -c n $dest.tgz
#
# computes the md5sum signature for the package
#
cd $buildir
md5sum $package.tgz > $package.md5
